| Title: | 'Domino Data R SDK' |
|---|---|
| Description: | A wrapper on top of the 'Domino Data Python SDK' library. It lets you query and access 'Domino Data Sources' directly from your R environment. Under the hood, 'Domino Data R SDK' leverages the API provided by the 'Domino Data Python SDK', which must be installed as a prerequisite. 'Domino' is a platform that makes it easy to run your code on scalable hardware, with integrated version control and collaboration features designed for analytical workflows. See <https://docs.dominodatalab.com/en/latest/api_guide/140b48/domino-data-api> for more information. |
| Authors: | Murat Cetin [cre], Gabriel Haim [aut] |
| Maintainer: | Murat Cetin <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.3.1 |
| Built: | 2026-05-26 07:20:02 UTC |
| Source: | https://github.com/dominodatalab/dominodatar |
Add credentials override for the right datasources
add_credentials(auth_type, config = list())add_credentials(auth_type, config = list())
auth_type |
Datasource Authentication type |
config |
existing config override to extend |
named list of override configuration values
Add override configuration values
add_override(..., .override = character())add_override(..., .override = character())
... |
named configuration values. |
.override |
a named character vector |
named list of override configuration values
Create a client to Domino datasources
datasource_client( api_key = NULL, token_file = NULL, token_url = NULL, token = NULL )datasource_client( api_key = NULL, token_file = NULL, token_url = NULL, token = NULL )
api_key |
string key to override the environment variable |
token_file |
location of file to read token from |
token_url |
url of the location to read the token from |
token |
token to be used to authenticate |
A domino_data.data_sources.DataSourceClient.
Properly escape a URL path
encode_url_path(url)encode_url_path(url)
url |
URL to properly escape |
Internal only to fix malformed URLs.
escaped url
Get URL for a file in a NetApp volume
get_file_url(client, volume_unique_name, file_name)get_file_url(client, volume_unique_name, file_name)
client |
As returned by |
volume_unique_name |
Unique name of the volume |
file_name |
Name of the file |
URL string for the file
Retrieve an object from a datasource
get_object(client, datasource, object, as = "raw", override = list())get_object(client, datasource, object, as = "raw", override = list())
client |
As returned by |
datasource |
The name of the datasource to query |
object |
The object to retrieve |
as |
Passed through to |
override |
Configuration values to override ( |
Raw vector representation of the object
Get a NetApp volume by name
get_volume(client, name)get_volume(client, name)
client |
As returned by |
name |
Unique name of the volume |
A Volume object
List files in a NetApp volume
list_files(client, volume_unique_name, prefix = "", page_size = 1000)list_files(client, volume_unique_name, prefix = "", page_size = 1000)
client |
As returned by |
volume_unique_name |
Unique name of the volume |
prefix |
Optional prefix to filter files |
page_size |
Optional number of files to fetch |
A vector of file paths
List the keys starting with prefix in an object store
list_keys(client, datasource, prefix = "", override = list(), page_size = 50)list_keys(client, datasource, prefix = "", override = list(), page_size = 50)
client |
As returned by |
datasource |
The name of the datasource to query |
prefix |
Prefix to filter keys to list |
override |
Configuration values to override ( |
page_size |
Number of objects to fetch |
A vector or string keys
List snapshots for a NetApp volume
list_snapshots(client, volume_unique_name, offset = NULL, limit = NULL)list_snapshots(client, volume_unique_name, offset = NULL, limit = NULL)
client |
As returned by |
volume_unique_name |
Unique name of the volume |
offset |
Optional offset for pagination |
limit |
Optional limit for pagination |
A list of RemotefsSnapshot objects
List NetApp volumes
list_volumes(client, offset = NULL, limit = NULL)list_volumes(client, offset = NULL, limit = NULL)
client |
As returned by |
offset |
Optional offset for pagination |
limit |
Optional limit for pagination |
A list of RemotefsVolume objects
Load AWS Credentials
load_aws_credentials(location, profile = NULL)load_aws_credentials(location, profile = NULL)
location |
file path where AWS credentials are located |
profile |
AWS profile or section to use |
named list of override configuration values
Load OAuth Credentials
load_oauth_credentials(env_var, path)load_oauth_credentials(env_var, path)
env_var |
the environment variable name containing the API proxy URL |
path |
the API endpoint path for retrieving the token |
named list of override configuration values
Make the HTTP request
make_request(verb, url, config, headers, request_body, write_disk)make_request(verb, url, config, headers, request_body, write_disk)
verb |
A character string containing an HTTP verb |
url |
Signed URL to download object at. |
config |
A list of config values for the REST call. |
headers |
A list of request headers for the REST call. |
request_body |
A character string containing request body data. |
write_disk |
An argument like |
Internal only to enable retry for malformed URLs.
a response object.
Create a client for NetApp volumes
netapp_volume_client(token_file = NULL, token_url = NULL, token = NULL)netapp_volume_client(token_file = NULL, token_url = NULL, token = NULL)
token_file |
location of file to read token from |
token_url |
url of the location to read the token from |
token |
token to be used to authenticate |
A domino_data.netapp_volumes.NetAppVolumeClient.
HTTP requests for Object Stores
object_http( verb = "GET", url, datasource_type, config = list(), headers = list(), request_body = "", write_disk = NULL )object_http( verb = "GET", url, datasource_type, config = list(), headers = list(), request_body = "", write_disk = NULL )
verb |
A character string containing an HTTP verb, defaulting to “GET”. |
url |
Signed URL to download object at. |
datasource_type |
Type of datasource the object is stored in. |
config |
A list of config values for the REST call. |
headers |
A list of request headers for the REST call. |
request_body |
A character string containing request body data. |
write_disk |
An argument like |
This is mostly for internal use by object store APIs.
a response object.
Upload an object to a datasource
put_object(client, datasource, object, what, override = list())put_object(client, datasource, object, what, override = list())
client |
As returned by |
datasource |
The name of the datasource to query |
object |
The object to retrieve |
what |
character vector, raw vector |
override |
Configuration values to override ( |
Raw vector representation of the object
Upload content to a NetApp volume
put_volume_object(client, volume_unique_name, object, what, override = list())put_volume_object(client, volume_unique_name, object, what, override = list())
client |
As returned by |
volume_unique_name |
Unique name of the volume |
object |
The object key to create/overwrite |
what |
character vector, raw vector |
override |
Configuration values to override ( |
HTTP status message
Install domino_data Python package
py_domino_data_install(version)py_domino_data_install(version)
version |
Version of the domino_data package to install. |
TRUE if installation was successful, FALSE otherwise.
Provide other options in case the package is used for local development.
py_select_interpreter()py_select_interpreter()
TRUE if a python binary was bound to reticulate, FALSE otherwise
Query a datasource and returns an arrow Table
query(client, datasource, query, override = list())query(client, datasource, query, override = list())
client |
As returned by |
datasource |
The name of the datasource to query |
query |
The query to run against the provided datasource |
override |
Configuration values to override ( |
An arrow::Table
Save an object from a datasource to a local file
save_object( client, datasource, object, file = basename(object), override = list() )save_object( client, datasource, object, file = basename(object), override = list() )
client |
As returned by |
datasource |
The name of the datasource to query |
object |
The object to retrieve |
file |
File path to save object at. Defaults to the object base name. |
override |
Configuration values to override ( |
Raw vector representation of the object
Save an object from a NetApp volume to a local file
save_volume_object( client, volume_unique_name, object, file = basename(object), override = list() )save_volume_object( client, volume_unique_name, object, file = basename(object), override = list() )
client |
As returned by |
volume_unique_name |
Unique name of the volume |
object |
The object to retrieve |
file |
File path to save object at. Defaults to the object base name. |
override |
Configuration values to override ( |
File path where object was saved
Upload a file to a datasource
upload_object(client, datasource, object, file, override = list())upload_object(client, datasource, object, file, override = list())
client |
As returned by |
datasource |
The name of the datasource to query |
object |
The object to retrieve |
file |
File path to upload.. |
override |
Configuration values to override ( |
Raw vector representation of the object
Upload a file to a NetApp volume
upload_volume_object( client, volume_unique_name, object, file, override = list() )upload_volume_object( client, volume_unique_name, object, file, override = list() )
client |
As returned by |
volume_unique_name |
Unique name of the volume |
object |
The object key in the volume |
file |
File path to upload |
override |
Configuration values to override ( |
HTTP status message